tendril.conventions package
===========================

Subpackages
-----------

.. toctree::

    tendril.conventions.motifs

Submodules
----------

.. toctree::

   tendril.conventions.electronics

Module contents
---------------

.. automodule:: tendril.conventions
    :members:
    :undoc-members:
    :show-inheritance:

Inheritance Diagram
-------------------

.. inheritance-diagram::
    tendril.conventions
    tendril.conventions.electronics
    tendril.conventions.motifs
    tendril.conventions.motifs.DLPF1
    tendril.conventions.motifs.ING_AD8421
    tendril.conventions.motifs.LPF1
    tendril.conventions.motifs.LREGS1
    tendril.conventions.motifs.ingbase
    tendril.conventions.motifs.motifbase
